@@ -44,6 +44,7 @@ class DictProxy(dict):
 
 def Connector(url, username, password, list_id, timeout=65):
     """ Sharepoint SOAP connector factory """
+    LOG.info('Connecting to Sharepoint (%s, %s, %s)' % (url, username, list_id))
     transport = WindowsHttpAuthenticated(username=username,
                                          password=password,
                                          timeout=timeout)
@@ -160,7 +161,7 @@ class ListEndpoint(object):
         # data must include the value of the primary key field            
         value_primary_key = data.get(self.primary_key)
         if primary_key_check and value_primary_key is None:
-            raise ValueError('No value for primary key "%s" found in update dict (%s)' % (self.primary_key, d))
+            raise ValueError('No value for primary key "%s" found in update dict (%s)' % (self.primary_key, data))
 
         data_keys = set(data.keys())
         all_fields = set(self.all_fields)
@@ -175,7 +176,7 @@ class ListEndpoint(object):
     def getItems(self, rowLimit=999999999, viewName=None):
         """ Return all list items without further filtering """
         items = self.service.GetListItems(self.list_id, viewName=viewName or self.viewName, rowLimit=rowLimit)
-        if items.listitems.data._ItemCount > 0:
+        if int(items.listitems.data._ItemCount) > 0:
             return [self._serializeListItem(item) for item in items.listitems.data.row]
         return []
 
@@ -265,7 +266,7 @@ class ListEndpoint(object):
     def deleteItems(self, *item_ids):
         """ Remove list items given by value of their primary key """
         batch = Element('Batch')
-        batch.append(Attribute('OnError','Continue')).append(Attribute('ListVersion','1'))
+        batch.append(Attribute('OnError','Return')).append(Attribute('ListVersion','1'))
         for i, item_id in enumerate(item_ids):
             method = Element('Method')
             method.append(Attribute('ID', str(i+1))).append(Attribute('Cmd', 'Delete'))
@@ -282,7 +283,7 @@ class ListEndpoint(object):
             through the value of the primary key inside the update dict.
         """
         batch = Element('Batch')
-        batch.append(Attribute('OnError','Continue')).append(Attribute('ListVersion','1'))
+        batch.append(Attribute('OnError','Return')).append(Attribute('ListVersion','1'))
         for i, d in enumerate(update_items):
             self._preflight(d)
             method = Element('Method')
@@ -301,7 +302,7 @@ class ListEndpoint(object):
             the result object.
         """
         batch = Element('Batch')
-        batch.append(Attribute('OnError','Continue')).append(Attribute('ListVersion','1'))
+        batch.append(Attribute('OnError','Return')).append(Attribute('ListVersion','1'))
         for i, d in enumerate(addable_items):
             self._preflight(d, primary_key_check=False)
             method = Element('Method')
